summaryrefslogtreecommitdiffstats
path: root/src/hardware.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/hardware.cpp')
-rw-r--r--src/hardware.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/hardware.cpp b/src/hardware.cpp
index 4d688f5..1b16289 100644
--- a/src/hardware.cpp
+++ b/src/hardware.cpp
@@ -306,7 +306,7 @@ void HardwareInfo::processMessage (msg_type type, TQString message, TQString val
} else if (value.startsWith("power")) {
TQTimer::singleShot(50, this, TQT_SLOT(emitPowerButtonPressed()));
} else if (value.startsWith("sleep") || value.startsWith("suspend")) {
- TQTimer::singleShot(50, this, TQT_SLOT(emitSleepButtonPressed()));
+ TQTimer::singleShot(50, this, TQT_SLOT(emitSuspendButtonPressed()));
} else if (value.startsWith("hibernate")) {
TQTimer::singleShot(50, this, TQT_SLOT(emitS2diskButtonPressed()));
} else if (value.startsWith("brightness-")) {
@@ -1357,9 +1357,9 @@ void HardwareInfo::emitPowerButtonPressed() {
}
/*!
* Function to emit the signal for the Sleep button.
*/
-void HardwareInfo::emitSleepButtonPressed() {
+void HardwareInfo::emitSuspendButtonPressed() {
if (sessionIsActive) {
emit sleepButtonPressed();
} else {
@@ -1357,9 +1357,9 @@ void HardwareInfo::emitPowerButtonPressed() {
}
/*!
- * Function to emit the signal for the Sleep button.
+ * Function to emit the signal for the Suspend button.
*/